@@ -16,7 +16,7 @@
 #include <stdint.h>
 
 struct zbinbuf{
-    int size, len;
+    int size, len, increment;
     char *buf;
 };
 
@@ -33,7 +33,7 @@ void zbinbuf_getstr(struct zbinbuf *zbb, int pos, char *str, int maxlen);
 void zbinbuf_getline(struct zbinbuf *zbb, int *pos, char *str, int maxlen);
 
 int zbinbuf_append_file(struct zbinbuf *zbb, const char *filename);
-int zbinbuf_write_to_file(struct zbinbuf *zbb, const char *filename);
+int zbinbuf_write_to_file(struct zbinbuf *zbb, const char *filename, int offset, int len);
 
 void zbinbuf_append_le_s16(struct zbinbuf *zbb, int16_t a);
 void zbinbuf_append_le_s32(struct zbinbuf *zbb, int32_t a);
