@@ -38,6 +38,7 @@ void z_putpixel8inv(SDL_Surface *surface, int x, int y, int color);
 void z_putpixel16inv(SDL_Surface *surface, int x, int y, int color);
 void z_putpixel24inv(SDL_Surface *surface, int x, int y, int color);
 void z_putpixel32inv(SDL_Surface *surface, int x, int y, int color);
+void z_putpixel_fmt(SDL_Surface *surface, int x, int y, int color, SDL_PixelFormat *format);
 
 int z_getpixel8(SDL_Surface *surface, int x, int y);
 int z_getpixel16(SDL_Surface *surface, int x, int y);
@@ -45,23 +46,28 @@ int z_getpixel24(SDL_Surface *surface, int x, int y);
 int z_getpixel32(SDL_Surface *surface, int x, int y);
 #define z_putpixel(s, x, y, c) zsdl->putpixel(s, x, y, c)
 int z_getpixel(SDL_Surface *surface, int x, int y);
+int z_getpixel_fmt(SDL_Surface *surface, int x, int y, SDL_PixelFormat *format);
 
 
-#define ZFONT_TRANSP     1
-#define ZFONT_CENTERX    2 
-#define ZFONT_CENTERY    4 
-#define ZFONT_RIGHT      8 
-#define ZFONT_SYNC      16
-#define ZFONT_CHAR      32
-#define ZFONT_DOUBLEHT  64
-#define ZFONT_DOUBLEHB 128
-#define ZFONT_USERHFLG 256
+#define ZFONT_TRANSP           1
+#define ZFONT_CENTERX          2 
+#define ZFONT_CENTERY          4 
+#define ZFONT_RIGHT            8 
+#define ZFONT_SYNC            16
+#define ZFONT_CHAR            32
+#define ZFONT_DOUBLEHT        64
+#define ZFONT_DOUBLEHB       128
+#define ZFONT_USERHFLG       256
+#define ZFONT_OUTLINE        512
+#define ZFONT_OUTLINE_FONT  1024
 #define ZFONT_USERH(h) (((h << 16) & 0xff0000) | ZFONT_USERHFLG)
 
 void zsdl_printf(SDL_Surface *surface, int x, int y, int color, int bgcolor, int flags, char *m, ...); 
 int zsdl_h2w(int font_h);
 int zsdl_max_font_h(int w, int h, char *text);
 
+short *zfont_create_outline(const short *font, int size_b, int font_h);
+
 
 int z_clip_pixel(SDL_Rect *clip, int x, int y);
 int z_overlapped_pixel(SDL_Rect *clip_rect, int x, int y);
