@@ -64,6 +64,8 @@ struct zzsdl *zsdl = NULL;
 #define _CRT_SECURE_NO_WARNINGS
 #endif
 
+static short *outline9x16;
+
 
 struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse){
 
@@ -95,6 +97,8 @@ struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse){
 	zsdl->font_w = zsdl_h2w(font_h);
     zsdl->format = screen->format;
 
+	outline9x16 = zfont_create_outline(font9x16, sizeof(font9x16), 16);
+
     //zsdl_font_save(screen);
     //zsdl_font_dump("e:\\down\\tmp\\font13x24.png", "font13x24.inc");
 //    zsdl_font_dump("e:\\down\\tmp\\font9x16.png", "font9x16.inc");
@@ -106,8 +110,10 @@ struct zzsdl *zsdl_init(SDL_Surface *screen, int font_h, int inverse){
    return zsdl;
 }
 
+
 void zsdl_free(void){
     if (!zsdl) return;
+	g_free(outline9x16);
     g_free(zsdl);
     zsdl = NULL;
 }
@@ -158,6 +164,21 @@ int zsdl_max_font_h(int w, int h, char *text){
 	return 13; 
 }
 
+short *zfont_create_outline(const short *font, int size_b, int font_h){
+	int i, len = size_b / sizeof(short);
+	short *out = (short *)g_malloc(size_b);
+
+	for (i = 0; i < len; i++){
+		out[i] = font[i];
+		if ((i % font_h) != 0) out[i] |= font[i - 1];
+		if (((i + 1) % font_h) != 0) out[i] |= font[i + 1];
+	} 
+	for (i = 0; i < len; i++){
+		out[i] |= ((unsigned short)out[i] << 1) | ((unsigned short)out[i] >> 1);
+	}
+
+	return out;
+}
 
 /* returns 1 if pixel is out of rect */
 int z_clip_pixel(SDL_Rect *clip, int x, int y){
@@ -308,6 +329,14 @@ void z_putpixel32inv(SDL_Surface *surface, int x, int y, int color){
 	}
 } */
 
+void z_putpixel_fmt(SDL_Surface *surface, int x, int y, int c, SDL_PixelFormat *format){
+	Uint8 r, g, b, a;
+
+	SDL_GetRGBA(c, format, &r, &g, &b, &a);
+	c = SDL_MapRGBA(surface->format, r, g, b, a);
+	z_putpixel(surface, x, y, c);
+}
+
 void z_putpixela(SDL_Surface *surface, int x, int y, int color, int a){
 	int fr, fg, fb, b, br, bg, bb, c;
 
@@ -391,6 +420,15 @@ int z_getpixel(SDL_Surface *surface, int x, int y){
     }
 }
 
+int z_getpixel_fmt(SDL_Surface *surface, int x, int y, SDL_PixelFormat *format){
+	Uint8 r, g, b, a;
+	int c = z_getpixel(surface, x, y);
+
+	SDL_GetRGBA(c, surface->format, &r, &g, &b, &a);
+	c = SDL_MapRGBA(format, r, g, b, a);
+	return c;
+}
+
 //static char bits[]={1, 2, 4, 8, 16, 32, 64, 128};
 static int sbits[]={1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384, 32768, 65536, 131072, 262144, 524288, 1048576};
 
@@ -404,6 +442,18 @@ void zsdl_printf(SDL_Surface *surface, int x, int y, int color, int bgcolor, int
 	int font_h;
 	int old_font_w = 0, old_font_h = 0;
 
+	if (flags & ZFONT_OUTLINE){
+		int flg = flags & ~ZFONT_OUTLINE;
+		flg |= ZFONT_OUTLINE_FONT;
+		flg |= ZFONT_TRANSP;
+
+		va_start(l, m);
+        s = g_strdup_vprintf(m, l);
+        va_end(l);
+		zsdl_printf(surface, x, y, bgcolor, 0, flg, "%s", s);
+		g_free(s);
+	}
+
 	if (flags & ZFONT_USERHFLG)	{
 		old_font_w = zsdl->font_w;
 		old_font_h = zsdl->font_h;
@@ -433,7 +483,11 @@ void zsdl_printf(SDL_Surface *surface, int x, int y, int color, int bgcolor, int
 
     if (zsdl->font_h == 16){
         for (c = s; *c != '\0'; c++){
-            fs = font9x16 + ((unsigned char) *c) * 16;
+			if (flags & ZFONT_OUTLINE_FONT)
+	            fs = outline9x16 + ((unsigned char) *c) * 16;
+			else
+				fs = font9x16 + ((unsigned char) *c) * 16;
+
             for (i = 0; i < 16; i++){
                 fi = i;
                 if (flags & (ZFONT_DOUBLEHT | ZFONT_DOUBLEHB)) fi = fi / 2;
