@@ -250,9 +250,13 @@ rep:;
 static void zselect_timers_check(struct zselect *zsel)
 {
     struct ztimer *t;
+	int timer_count = 0;
     ztime interval = zselect_time() - zsel->last_time;
 
-    foreach(t, zsel->timers) t->interval -= interval;
+    foreach(t, zsel->timers) {
+		t->interval -= interval;
+		timer_count++;
+	}
     ch:
     foreach(t, zsel->timers){
         if (t->interval <= 0) {
@@ -267,6 +271,7 @@ static void zselect_timers_check(struct zselect *zsel)
 			if (zsel->profile) zselect_handle_profile(zsel, &start, tt->func, tt->fname);
             g_free(tt);
             CHK_BH;
+			if (timer_count-- == 0) break;
             goto ch;
         }else{
             break;
